#
# spec file for package ola
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with python
%bcond_without tcmalloc
%bcond_with java
Name:           ola
Version:        0.10.9
Release:        6.1
Summary:        Open Lighting Architecture (OLA)
License:        GPL-2.0-only
Group:          Productivity/Other
URL:            https://www.openlighting.org/ola/
Source0:        https://github.com/OpenLightingProject/ola/releases/download/%{version}/ola-%{version}.tar.gz
Source1:        baselibs.conf
Patch1:         ola-remove_defines.patch
%if %{defined suse_version} && 0%{?suse_version} > 1600
Patch2:         ola-Fix-protoc-version-checking-since-v20-x.patch
%endif
# https://github.com/OpenLightingProject/ola/issues/1966
Patch3:         https://github.com/OpenLightingProject/ola/commit/d9b9c78645c578adb7c07b692842e841c48310be.patch
BuildRequires:  automake >= 1.11.2
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(avahi-core)
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libftdi1)
BuildRequires:  pkgconfig(libmicrohttpd)
BuildRequires:  pkgconfig(libusb)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(uuid)
%if %{defined suse_version}&& 0%{?suse_version} > 1600
BuildRequires:  protobuf21-devel
%else
BuildRequires:  protobuf-devel
%endif
%if %{with java}
BuildRequires:  java-devel
BuildRequires:  maven
  %if %{defined fedora}
BuildRequires:  java-protobuf
  %else
BuildRequires:  protobuf-java
  %endif
%endif
%if %{with python}
BuildRequires:  python3-devel
BuildRequires:  python3-protobuf
%endif
%if %{with tcmalloc}
BuildRequires:  pkgconfig(libtcmalloc)
%endif

%description
The Open Lighting Architecture (OLA) consists of two parts, the daemon olad and the library, libola.

%package -n libola0
Summary:        More Open Lighting Architecture (OLA) shared libraries
License:        LGPL-2.1-only
Group:          Productivity/Other

%description -n libola0
Additional OLA libraries, required for third-party applications

%package -n libola1
Summary:        Open Lighting Architecture (OLA) shared libraries
License:        LGPL-2.1-only
Group:          Productivity/Other

%description -n libola1
The OLA libraries, required for third-party applications

%package -n libola-devel
Summary:        Open Lighting Architecture (OLA) development headers
License:        LGPL-2.1-only
Group:          Development/Libraries/Other
Requires:       libmicrohttpd-devel
Requires:       libola0 = %{version}
Requires:       libola1 = %{version}
Requires:       libuuid-devel
%if %{defined suse_version}&& 0%{?suse_version} > 1600
BuildRequires:  protobuf21-devel
%else
BuildRequires:  protobuf-devel
%endif
Requires:       zlib-devel

%description -n libola-devel
The OLA library headers, required to use the OLA library
in third-party applications

%if %{with python}
%package -n python3-ola
Summary:        Python bindings for Open Lighting Architecture (OLA)
License:        LGPL-2.1-only
Group:          Development/Languages/Python
Requires:       python3-protobuf
BuildArch:      noarch

%description -n python3-ola
Python bindings for Open Lighting Architecture (OLA).
Used in third-party applications written in  python.
%endif

%prep
%setup -q
%autopatch -p1

%build
autoreconf -i
%configure --disable-static \
%if %{with python}
    --enable-python-libs \
%else
    --disable-python-libs \
%endif
%if %{with java}
    --enable-java-libs \
%endif
%if %{with tcmalloc}
    --enable-tcmalloc \
%endif
#    --disable-examples
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}

%post -n libola0 -p /sbin/ldconfig
%postun -n libola0 -p /sbin/ldconfig

%post -n libola1 -p /sbin/ldconfig
%postun -n libola1 -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS ChangeLog README NEWS TODO
%{_bindir}/olad
%{_bindir}/ola_*
%{_bindir}/rdmpro_sniffer
%{_bindir}/usbpro_firmware
%{_datadir}/ola/
%{_datadir}/olad/
%{_mandir}/man1/*

%files -n libola0
%{_libdir}/libola*.so.0*

%files -n libola1
%{_libdir}/libola.so.1*

%files -n libola-devel
%{_includedir}/ola/
%{_includedir}/olad/
%{_libdir}/libola*.so
%{_libdir}/pkgconfig/libola*.pc

%if %{with python}
%files -n python3-ola
%{python3_sitelib}/*
%endif

%changelog
* Wed Mar  9 2016 cingulingu1@gmail.com
- Update to 0.10.0:
  * Remove a number of obsolete Autotools macros, we now require Automake 1.11.2 #931
  * Work around the case where an Enttec USB Pro widget doesn't respond #341
  * Fix a crash if a client disconnects during RDM discovery #950
  * Stop e131_transmit_test from segfaulting #966
  * Split libolaserver into two parts to stop dpkg-shlibdeps warnings
  * Add better logging for open()
  * Added more man pages.
  * Added a DMX keypad to the new web UI
  * OLA Trigger config to control Philips Hue Lux lights
  * Added hotplug support for usbdmx devices
  * Add support for JaRule widgets.
  * Add UUCP locking support #888
  * Fix issues encountered when packaging for openSUSE and fedora #904
  * Add support for the Nodle U1 widget
  * Add validation of OSC output format types
  * Add an example Stdin handler to the documentation
  * Increase the port limit for E1.31 up to 512 from 128
- Removed upstream merged fix-invalid-shebang-on-modules.patch
* Fri Nov  6 2015 cingulingu1@gmail.com
- Updated to 0.9.8:
  * Added fix-invalid-shebang-on-modules.patch
  * Made python subpackage optional
